import { jsx as _jsx } from "react/jsx-runtime";
import { useDatasource } from "@nexcodepl/endpoint-client";
import { useStoreState } from "@nexcodepl/react-store";
import { useEffect } from "react";
import { useRouteDataContext } from "./routeDataContext.js";
import { EndpointStaticData } from "./Static.endpoint.js";
import { useStaticDataContext } from "./staticDataContext.js";
import { HtmlHeadWrapper } from "./HtmlHeadWrapper.js";
export function StaticDataProvider({ route, element, loader, error, routes, globalData, wrapper, RouteDataContext, basePath = "", }) {
    const staticDataContext = useStaticDataContext();
    const routeDataContext = useRouteDataContext({
        globalData,
        route,
        routes,
        routeData: staticDataContext.getData(route.id),
    });
    const dsRouteData = useDatasource({ ...EndpointStaticData, url: basePath + EndpointStaticData.url });
    const dsRouteDataState = useStoreState(dsRouteData.state);
    useEffect(() => {
        const routeData = staticDataContext.getData(route.id) ?? null;
        routeDataContext.routeDataStore.set(routeData);
        if (!routeData) {
            dsRouteData.load({ params: { dataId: route.id } });
        }
    }, [route.id]);
    useEffect(() => {
        if (dsRouteDataState.state === "completed") {
            routeDataContext.routeDataStore.set(dsRouteDataState.response);
            staticDataContext.setData(route.id, dsRouteDataState.response);
        }
    }, [dsRouteDataState.state]);
    return (_jsx(RouteDataContext.Provider, { value: routeDataContext, children: wrapper({
            routeDataState: dsRouteDataState.state,
            route,
            children: dsRouteDataState.state === "error" ? (error(dsRouteDataState)) : dsRouteDataState.state === "pending" ||
                routeDataContext.routeData === null ||
                route.id !== routeDataContext.routeData.data?.id ? (loader) : (_jsx(HtmlHeadWrapper, { routeDataContext: RouteDataContext, children: element })),
        }) }));
}
